@@ -43,15 +43,19 @@ mean_sd <- function(x,
   s <- sd(x, na.rm = na_rm)
 
   if (show_n =="always" | any(is.na(x))) { 
-    rtn <- paste0(frmt(as.integer(n)), "; ", frmt(m), " $\\pm$ ", frmt(s))
+    rtn <- paste0(frmt(as.integer(n), digits), "; ", frmt(m, digits), " $\\pm$ ", frmt(s, digits))
   } else { 
-    rtn <- paste0(frmt(m), " $\\pm$ ", frmt(s))
+    rtn <- paste0(frmt(m, digits), " $\\pm$ ", frmt(s, digits))
   }
 
   if (denote_sd == "paren") { 
     rtn <- gsub("\\$\\\\pm\\$\\s(.*)", "\\(\\1\\)", rtn)
   }
 
+  if (markup == "markdown") { 
+    rtn <- gsub("\\$\\\\pm\\$", "&plusmn;", rtn)
+  }
+
   return(rtn)
 }
 
